package com.myorg;

import java.util.HashMap;
import java.util.Map;

import software.amazon.awscdk.core.Construct;
import software.amazon.awscdk.core.Duration;
import software.amazon.awscdk.core.Stack;
import software.amazon.awscdk.core.StackProps;

import software.amazon.awscdk.services.lambda.Code;
import software.amazon.awscdk.services.lambda.Function;
import software.amazon.awscdk.services.lambda.Runtime;
import software.amazon.awscdk.services.lambda.StartingPosition;

import software.amazon.awscdk.services.lambda.nodejs.NodejsFunction;

import software.amazon.awscdk.services.apigateway.LambdaRestApi;

import software.amazon.awscdk.services.dynamodb.Attribute;
import software.amazon.awscdk.services.dynamodb.AttributeType;
import software.amazon.awscdk.services.dynamodb.Table;

import software.amazon.awscdk.services.lambda.eventsources.DynamoEventSourceProps;
import software.amazon.awscdk.services.lambda.eventsources.DynamoEventSource;

public class CreateCommandRestControllerStack extends Stack {
    public CreateCommandRestControllerStack(final Construct scope, final String id) {
        this(scope, id, null);
    }

    public CreateCommandRestControllerStack(final Construct scope, final String id, final StackProps props) {
        super(scope, id, props);

        // DynamoDB table
        final Attribute partitionKey = Attribute.builder()
                .name("id")
                .type(AttributeType.NUMBER)
                .build();
        //TableProps tableProps = TableProps.builder()
        //.tableName("Products")
        //.partitionKey(partitionKey)
        // The default removal policy is RETAIN, which means that cdk destroy will not attempt to delete
        // the new table, and it will remain in your account until manually deleted. By setting the policy to
        // DESTROY, cdk destroy will delete the table (even if it has data in it)
        //.removalPolicy(RemovalPolicy.DESTROY)
        //.build();

        final Table productTable = Table.Builder.create(this, "Product")
        .partitionKey(partitionKey)
        .build();

        // Define a new Lambda resource.
        //final Function hello = Function.Builder.create(this, "HelloHandler")
        //.runtime(Runtime.NODEJS_12_X) // execution environment
        //.code(Code.fromAsset("resources/lambda")) // code loaded from the resources/lambda folder on the root of the CDK project.
        //.handler("hello.handler") // file is "hello.js", function is "handler"
        //.build();

        final Map<String, String> environment = new HashMap<>();
        environment.put("PRODUCT_TABLE", productTable.getTableName());

		final Function getAllProducts = Function.Builder.create(this, "GetProductsHandler")
        .runtime(Runtime.NODEJS_12_X) // execution environment
        .code(Code.fromAsset("resources/lambda")) // code loaded from the resources/lambda folder on the root of the CDK project.
        .handler("get-all-products.getAllProductsHandler") // file is "hello.js", function is "handler"
        .environment(environment)
        .build();

        productTable.grantReadData(getAllProducts);

        final DynamoEventSource productEventSource = DynamoEventSource.Builder.create(productTable)
        .startingPosition(StartingPosition.LATEST)
        .batchSize(1)
        .build();

        //Function that will handle DynamoDB event sources.
        final NodejsFunction sendProductEventWrapper = NodejsFunction.Builder
        .create(this, "SendProductEventHandler")
        // Using absolute path as argument to entry due to https://github.com/aws/aws-cdk/issues/8902
        .entry("/Users/et/sandbox/AWS/aws-cqrs/02-ecom-create-command-rest-controller/resources/lambda/send-product-event.js") // add the path to the file that holds the code
        .handler("handler") // function than handles the code
        .runtime(Runtime.NODEJS_12_X)
        .timeout(Duration.seconds(15))
        .build();

        // sendProductEventWrapper.addEventSource(productEventSource);
        

        // This function will consume the 
        // Define an API Gateway REST API resource backed by our "hello" function.
        LambdaRestApi.Builder.create(this, "Endpoint")
        .handler(getAllProducts)
        .build();

        
    }
}
